@@ -47,118 +47,6 @@ EPC_SUPER_FUNCTIONS = {
 # ------- EPC FUNCTIONS -------------------------------------------------
 # -----------------------------------------------------------------------
 
-# ----- Tempereature Sensor -------
-def _0011E0(edt):
-        return float(int.from_bytes(edt, 'big')) / 10
-
-
-# ----- Home Air conditioner -------
-def _0130A0(edt):
-    op_mode = int.from_bytes(edt, 'big')
-    values = {
-       0x41: 'auto',
-       0x31: 'minimum',
-       0x32: 'low',
-       0x33: 'medium-low',
-       0x34: 'medium',
-       0x35: 'medium-high',
-       0x36: 'high',
-       0x37: 'very-high',
-       0x38: 'max'
-    }
-    return values.get(op_mode, "Invalid setting")
-
-# Automatic control of air flow direction setting
-def _0130A1(edt):
-    op_mode = int.from_bytes(edt, 'big')
-    values = {
-       0x41: 'auto',
-       0x42: 'non-auto',
-       0x43: 'auto-vert',
-       0x44: 'auto-horiz'
-    }
-    return values.get(op_mode, "Invalid setting")
-
-def _0130AA(edt):
-    op_mode = int.from_bytes(edt, 'big')
-    # print(hex(op_mode))
-    values = {
-      0x40: 'Normal operation',
-      0x41: 'Defrosting',
-      0x42: 'Preheating',
-      0x43: 'Heat removal'
-      }
-    # return({'special':hex(op_mode)})
-    return values.get(op_mode, "invalid_setting")
-
-# Automatic swing of air flow direction setting
-def _0130A3(edt):
-    op_mode = int.from_bytes(edt, 'big')
-    values = {
-       0x31: 'not-used',
-       0x41: 'vert',
-       0x42: 'horiz',
-       0x43: 'vert-horiz'
-    }
-    return values.get(op_mode, "invalid_setting")
-
-# Air flow direction (vertical) setting
-def _0130A4(edt):
-    op_mode = int.from_bytes(edt, 'big')
-    values = {
-      0x41: 'upper',
-      0x44: 'upper-central',
-      0x43: 'central',
-      0x45: 'lower-central',
-      0x42: 'lower'
-      }
-    # return({'special':hex(op_mode)})
-    return values.get(op_mode, "invalid_setting")
-
-# Air flow direction (horiziontal) setting
-def _0130A5(edt):
-    # complies with version 2.01 Release a (page 3-88)
-    op_mode = int.from_bytes(edt, 'big')
-    values = {
-      0x41: 'rc-right',
-      0x42: 'left-lc',
-      0x43: 'lc-center-rc',
-      0x44: 'left-lc-rc-right',
-      0x51: 'right',
-      0x52: 'rc',
-      0x54: 'center',
-      0x55: 'center-right',
-      0x56: 'center-rc',
-      0x57: 'center-rc-right',
-      0x58: 'lc',
-      0x59: 'lc-right',
-      0x5A: 'lc-rc',
-      0x60: 'left',
-      0x61: 'left-right',
-      0x62: 'left-rc',
-      0x63: 'left-rc-right',
-      0x64: 'left-center',
-      0x65: 'left-center-right',
-      0x66: 'left-center-rc',
-      0x67: 'left-center-rc-right',
-      0x69: 'left-lc-right',
-      0x6A: 'left-lc-rc'
-      }
-    return values.get(op_mode, "invalid_setting")
-
-# Operation mode
-def _0130B0(edt):
-    op_mode = int.from_bytes(edt, 'big')
-    values = {
-       0x41: 'auto',
-       0x42: 'cool',
-       0x43: 'heat',
-       0x44: 'dry',
-       0x45: 'fan_only',
-       0x40: 'other'
-    }
-    return values.get(op_mode, "invalid_setting")
-
 def _0260EO(edt):
     op_mode = int.from_bytes(edt, 'big')
     values = {
